@@ -9,4 +9,6 @@ from .user import *
 from .news import *
 from .notice import *
 from .album import *
-from .video import *
\ No newline at end of file
+from .video import *
+from .school import *
+from .semester import *
\ No newline at end of file
