@@ -30,16 +30,16 @@ class Requester(object):
                 self.server = "{}://{}".format(protocol, host)
 
     def check_res(self, data):
-        return data, True
+        return data, 0
 
-    def _get_method(self, route, params={}, headers={}):
+    def _get_method(self, route, params={}, headers={}, timeout=3600):
         url = "{}{}".format(self.server, route)
         headers.update(self.headers)
         res = requests.get(url=url, headers=headers, params=params)
         try:
             res.raise_for_status()
             data = res.json()
-            data, success = self.check_res(data)
+            data, code = self.check_res(data)
         except (Exception,) as e:
             import traceback
             print("error in {}".format(url))
@@ -51,7 +51,7 @@ class Requester(object):
     def _download_method(self, route, file_path, params={}, headers={}):
         url = "{}{}".format(self.server, route)
         headers.update(self.headers)
-        res = requests.get(url=url, headers=headers, params=params)
+        res = requests.get(url=url, headers=headers, params=params, timeout=3600)
         try:
             res.raise_for_status()
             with open(file_path, "wb") as code:
@@ -63,12 +63,12 @@ class Requester(object):
     def _post_method(self, route, data={}, headers={}):
         url = "{}{}".format(self.server, route)
         headers.update(self.headers)
-        res = requests.post(url=url, json=data, headers=headers)
+        res = requests.post(url=url, json=data, headers=headers, timeout=3600)
         try:
             res.raise_for_status()
             print(res.text)
             data = res.json()
-            data, success = self.check_res(data)
+            data, code = self.check_res(data)
         except (Exception,):
             print(res.text)
             return None
@@ -77,12 +77,12 @@ class Requester(object):
     def _put_method(self, route, data={}, headers={}):
         url = "{}{}".format(self.server, route)
         headers.update(self.headers)
-        res = requests.put(url=url, json=data, headers=headers)
+        res = requests.put(url=url, json=data, headers=headers, timeout=3600)
         try:
             res.raise_for_status()
             print(res.text)
             data = res.json()
-            data, success = self.check_res(data)
+            data, code = self.check_res(data)
         except (Exception,):
             print(res.text)
             return None
@@ -91,12 +91,12 @@ class Requester(object):
     def _delete_method(self, route, data={}, headers={}):
         url = "{}{}".format(self.server, route)
         headers.update(self.headers)
-        res = requests.delete(url=url, json=data, headers=headers)
+        res = requests.delete(url=url, json=data, headers=headers, timeout=3600)
         try:
             res.raise_for_status()
             print(res.text)
             data = res.json()
-            data, success = self.check_res(data)
+            data, code = self.check_res(data)
         except (Exception,):
             print(res.text)
             return None
@@ -109,7 +109,7 @@ class Requester(object):
         try:
             res.raise_for_status()
             data = res.json()
-            data, success = self.check_res(data)
+            data, code = self.check_res(data)
         except (Exception,):
             print(res.text)
             return None
@@ -121,7 +121,15 @@ class Requester(object):
             value_list.append(str(info[k]))
         return "-".join(value_list)
 
-    def wrap_map(self, func_name, key_names, value_name, limit=300):
+    def get_res_count(self, res):
+        count = res.get('count', None) if isinstance(res, dict) else res
+        return count
+
+    def get_res_data(self, res):
+        data = res.get('results', None) if isinstance(res, dict) else res
+        return data
+
+    def wrap_map(self, func_name, key_names, value_name, limit=100):
         key_map = {}
         count, offset = None, 0
         while True:
@@ -131,10 +139,10 @@ class Requester(object):
                 res = getattr(self, func_name)(params={'limit': limit, 'offset': offset})
             else:
                 res = getattr(self, func_name)(params={'limit': limit})
-            count = res.get('count', None) if isinstance(res, dict) else res
+            count = self.get_res_count(res)
             if count is None:
                 raise AttributeError("data have no count")
-            data = res.get('results', None) if isinstance(res, dict) else res
+            data = self.get_res_data(res)
             if data is None:
                 raise AttributeError("data have no results")
             for item in data:
