@@ -1,3 +1,5 @@
+import time
+import datetime
 import traceback
 from classcard_dataclient.client.action import DataClient
 from config import SCHOOL_NAME
@@ -20,6 +22,10 @@ class BaseSync(object):
 
     def start(self):
         try:
+            logger.info(">>> Start {} On:".format(self.__class__.__name__, datetime.datetime.now()))
             self.sync()
         except (Exception,):
-            logger.error("Error: sync error, Detail: {}".format(traceback.print_exc()))
+            logger.error(">>> Error: sync error, Detail: {}".format(traceback.print_exc()))
+            time.sleep(10)
+        finally:
+            logger.info(">>> Finish {} On:".format(self.__class__.__name__, datetime.datetime.now()))
